==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/AppconfiginstanceRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfiginstance;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class AppconfiginstanceRequest extends EntityRequest<Appconfiginstance> {

    public AppconfiginstanceRequest(ContextPath contextPath, Optional<Object> value) {
        super(Appconfiginstance.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public AppconfigmasterRequest appconfiginstance_appconfigmaster() {
        return new AppconfigmasterRequest(contextPath.addSegment("appconfiginstance_appconfigmaster"), Optional.empty());
    }

    public OrganizationRequest organization_appconfiginstance_appconfiginstance() {
        return new OrganizationRequest(contextPath.addSegment("organization_appconfiginstance_appconfiginstance"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_createdonbehalfby"), Optional.empty());
    }

    public AppconfigRequest appconfiginstance_appconfig() {
        return new AppconfigRequest(contextPath.addSegment("appconfiginstance_appconfig"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_modifiedby"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_createdby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_createdby"), Optional.empty());
    }

    @Function(name = "RetrieveUnpublished")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<Appconfiginstance> retrieveUnpublished() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new FunctionRequestReturningNonCollectionUnwrapped<Appconfiginstance>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublished"), Appconfiginstance.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/request/AppconfiginstanceRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfiginstance;

@JsonIgnoreType
public class AppconfiginstanceRequest extends EntityRequest<Appconfiginstance> {

    public AppconfiginstanceRequest(ContextPath contextPath, Optional<Object> value) {
        super(Appconfiginstance.class, contextPath, value);
    }

    public AppconfigmasterRequest appconfiginstance_appconfigmaster() {
        return new AppconfigmasterRequest(contextPath.addSegment("appconfiginstance_appconfigmaster"), Optional.empty());
    }

    public OrganizationRequest organization_appconfiginstance_appconfiginstance() {
        return new OrganizationRequest(contextPath.addSegment("organization_appconfiginstance_appconfiginstance"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_createdonbehalfby"), Optional.empty());
    }

    public AppconfigRequest appconfiginstance_appconfig() {
        return new AppconfigRequest(contextPath.addSegment("appconfiginstance_appconfig"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_modifiedby"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest appconfiginstance_createdby() {
        return new SystemuserRequest(contextPath.addSegment("appconfiginstance_createdby"), Optional.empty());
    }

    @Function(name = "RetrieveUnpublished")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<Appconfiginstance> retrieveUnpublished() {
        Map<String, TypedObject> _parameters = ParameterMap.empty();
        return new FunctionRequestReturningNonCollectionUnwrapped<Appconfiginstance>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveUnpublished"), Appconfiginstance.class, _parameters);
    }

}
